==> haskell-mono-traversable-1.0.10.0-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.10.0
id: mono-traversable-1.0.10.0-B2DEVKzuXVx2ntjE95AtE2
key: mono-traversable-1.0.10.0-B2DEVKzuXVx2ntjE95AtE2
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: e411adc3f19ae525d561e522c70d1174
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.3/site-local/mono-traversable-1.0.10.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/mono-traversable-1.0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/mono-traversable-1.0.10.0
hs-libraries: HSmono-traversable-1.0.10.0-B2DEVKzuXVx2ntjE95AtE2
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-BISrknrydugK8yp2XIgTJd
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-algorithms-0.8.0.1-BIHTnGuwAIGGosyEgeh1Gy
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.10.0-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.10.0
id: mono-traversable-1.0.10.0-B0DKPg4maVQ2n29eDn0uVT
key: mono-traversable-1.0.10.0-B0DKPg4maVQ2n29eDn0uVT
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, John Wiegley, Greg Weber
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>
category: Data
abi: 3b18170e97f6991e1be2afbce06a5089
exposed: True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences
hidden-modules: Paths_mono_traversable
import-dirs: /usr/lib/ghc-8.6.3/site-local/mono-traversable-1.0.10.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/mono-traversable-1.0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/mono-traversable-1.0.10.0
hs-libraries: HSmono-traversable-1.0.10.0-B0DKPg4maVQ2n29eDn0uVT
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    split-0.2.3.3-9O3ah5XNSacJuZjDAE6BjK text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-HO72tBDce9GHcBPxpae42I
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
    vector-algorithms-0.8.0.1-BIHTnGuwAIGGosyEgeh1Gy
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
